import{O as d}from"./workspaceStore.9d8638ec.js";import{d as l,W as i,X as u,b as a,w as o,u as n,o as c,aF as s,d9 as f,d8 as b}from"./vue-router.c5124aea.js";import"./url.a882d197.js";import"./colorHelpers.89979f79.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="eb5f448a-e934-4253-8b01-7cb21d1ef60f",e._sentryDebugIdIdentifier="sentry-dbid-eb5f448a-e934-4253-8b01-7cb21d1ef60f")}catch{}})();const w=l({__name:"OidcLogoutCallback",setup(e){return i(async()=>{await new d().logoutCallback()}),(t,r)=>(c(),u("div",null,[a(n(f),null,{default:o(()=>[s("You're authenticated")]),_:1}),a(n(b),null,{default:o(()=>[s(" This window should close automatically. Please close it manually if it doesn't. ")]),_:1})]))}});export{w as default};
//# sourceMappingURL=OidcLogoutCallback.7130fb05.js.map
