import{eN as t,eO as r}from"./vue-router.c5124aea.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="5fa1b19b-db61-46e7-8834-b7f5c80b46fb",e._sentryDebugIdIdentifier="sentry-dbid-5fa1b19b-db61-46e7-8834-b7f5c80b46fb")}catch{}})();function d(e,n){return t(1,arguments),r(e,Date.now(),n)}export{d as f};
//# sourceMappingURL=index.ab21d327.js.map
