import{E as y}from"./api.c9850817.js";import{C as c}from"./ContentLayout.9b24f578.js";import{d as w,L as g,N as f,e as _,c as a,w as l,o as i,b as n,u as o,R as s}from"./vue-router.c5124aea.js";import{K as v,_ as K,W as R,E,a as T}from"./WorkflowView.2beb9071.js";import{A as p,T as V}from"./TabPane.d034fd1b.js";import"./fetch.06388243.js";import"./metadata.3563316e.js";import"./PhBug.vue.aa92508e.js";import"./PhCheckCircle.vue.7bd19eba.js";import"./PhKanban.vue.f0c956cb.js";import"./PhWebhooksLogo.vue.6c16e7ea.js";import"./polling.0af81052.js";import"./asyncComputed.492220e2.js";import"./PhQuestion.vue.b96fa7b2.js";import"./ant-design.8d54eea4.js";import"./index.31f5d814.js";import"./index.ab21d327.js";import"./index.ef3569d7.js";import"./CollapsePanel.056a32ae.js";import"./index.6763cab6.js";import"./index.2d35ff65.js";import"./Badge.2abe7f2d.js";import"./PhArrowCounterClockwise.vue.e4dedd55.js";import"./Workflow.37a53477.js";import"./validations.d974ced3.js";import"./string.243c4431.js";import"./uuid.e585e323.js";import"./index.155c96bd.js";import"./workspaces.7fd2e728.js";import"./workspaceStore.9d8638ec.js";import"./url.a882d197.js";import"./colorHelpers.89979f79.js";import"./record.3c40de6b.js";import"./index.1c47d0a7.js";import"./PhArrowDown.vue.8f545c64.js";import"./Card.44cc8533.js";import"./LoadingOutlined.e0624b0a.js";import"./DeleteOutlined.b28c52e2.js";import"./PhDownloadSimple.vue.cf64ee19.js";import"./utils.4e8fd924.js";import"./LoadingContainer.2d21a590.js";(function(){try{var r=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(r._sentryDebugIds=r._sentryDebugIds||{},r._sentryDebugIds[t]="94cfb8c1-f77e-4edc-b630-8fb893b92df4",r._sentryDebugIdIdentifier="sentry-dbid-94cfb8c1-f77e-4edc-b630-8fb893b92df4")}catch{}})();const yo=w({__name:"WorkflowThreads",setup(r){const t=new E,m=new T,d=new g(f.array(f.string()),"kanban-selected-stages"),u=new y,e=_("kanban");return(W,b)=>(i(),a(c,{"full-width":""},{default:l(()=>[n(o(V),{activeKey:e.value,"onUpdate:activeKey":b[0]||(b[0]=k=>e.value=k)},{default:l(()=>[n(o(p),{key:"kanban",tab:"Kanban View"}),n(o(p),{key:"table",tab:"Table View"}),n(o(p),{key:"workflow",tab:"Workflow View"})]),_:1},8,["activeKey"]),e.value==="kanban"?(i(),a(v,{key:0,"kanban-repository":o(t),"kanban-stages-storage":o(d),"stage-run-repository":o(m)},null,8,["kanban-repository","kanban-stages-storage","stage-run-repository"])):s("",!0),e.value==="table"?(i(),a(K,{key:1,"kanban-repository":o(t)},null,8,["kanban-repository"])):s("",!0),e.value==="workflow"?(i(),a(R,{key:2,"kanban-repository":o(t),"workflow-api":o(u)},null,8,["kanban-repository","workflow-api"])):s("",!0)]),_:1}))}});export{yo as default};
//# sourceMappingURL=WorkflowThreads.2f946a96.js.map
