import{d as a,o,X as s,b as d,u as c,bx as r,$ as _}from"./vue-router.c5124aea.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="38ec67d8-cd1b-4e62-ae77-9796ba68c861",e._sentryDebugIdIdentifier="sentry-dbid-38ec67d8-cd1b-4e62-ae77-9796ba68c861")}catch{}})();const i={class:"centered"},f=a({__name:"LoadingContainer",setup(e){return(n,t)=>(o(),s("div",i,[d(c(r))]))}});const u=_(f,[["__scopeId","data-v-52e6209a"]]);export{u as L};
//# sourceMappingURL=LoadingContainer.2d21a590.js.map
