import{d,o as r,c as o,w as s,b as f,Z as c,u as n,dd as u,ez as i,eC as l,bP as b}from"./vue-router.c5124aea.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="f892e0c4-ca22-4b24-8f48-2dd4b7b89d25",e._sentryDebugIdIdentifier="sentry-dbid-f892e0c4-ca22-4b24-8f48-2dd4b7b89d25")}catch{}})();const _=d({__name:"AbstraButton",setup(e){return(t,a)=>(r(),o(n(b),i(l(t.$attrs)),{default:s(()=>[f(n(u),{style:{display:"flex","align-items":"center","justify-content":"center",gap:"5px"}},{default:s(()=>[c(t.$slots,"default")]),_:3})]),_:3},16))}});export{_};
//# sourceMappingURL=AbstraButton.vue_vue_type_script_setup_true_lang.c50d2ebb.js.map
