import{C as t,E as i,K as d,a as f,M as c,c as l,P as y,R as g,S as u,b,T as k,U as p,e as w,l as D}from"./toggleHighContrast.5c897e2b.js";import"./vue-router.c5124aea.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="a634d1c1-13aa-424f-a084-316f644c4729",e._sentryDebugIdIdentifier="sentry-dbid-a634d1c1-13aa-424f-a084-316f644c4729")}catch{}})();export{t as CancellationTokenSource,i as Emitter,d as KeyCode,f as KeyMod,c as MarkerSeverity,l as MarkerTag,y as Position,g as Range,u as Selection,b as SelectionDirection,k as Token,p as Uri,w as editor,D as languages};
//# sourceMappingURL=editor.main.4b29607d.js.map
