import{O as r}from"./workspaceStore.9d8638ec.js";import{d as i,W as l,X as c,b as t,w as n,u as o,o as u,aF as d,d9 as f,d8 as _}from"./vue-router.c5124aea.js";import"./url.a882d197.js";import"./colorHelpers.89979f79.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="0cdc102a-ce9d-43fa-af0e-b02685c0a531",e._sentryDebugIdIdentifier="sentry-dbid-0cdc102a-ce9d-43fa-af0e-b02685c0a531")}catch{}})();const w=i({__name:"OidcLoginCallback",setup(e){return l(async()=>{await new r().loginCallback()}),(a,s)=>(u(),c("div",null,[t(o(f),null,{default:n(()=>[d("You're authenticated")]),_:1}),t(o(_),null,{default:n(()=>[d(" This window should close automatically. Please close it manually if it doesn't. ")]),_:1})]))}});export{w as default};
//# sourceMappingURL=OidcLoginCallback.8d2d87c4.js.map
