import{_ as f}from"./AbstraLogo.vue_vue_type_script_setup_true_lang.1d6e5f8b.js";import{B as y}from"./BaseLayout.fbdcf663.js";import{d as p,D as m,K as b,$ as u,aZ as v,a_ as g,o as _,X as h,a as s,Y as a,ed as w,eq as S,W as k,c as L,w as n,b as i,u as $}from"./vue-router.c5124aea.js";import{u as x}from"./editor.3f12aea3.js";import{b as B}from"./index.202abc24.js";import"./Logo.b4a8ebe2.js";import"./workspaceStore.9d8638ec.js";import"./url.a882d197.js";import"./colorHelpers.89979f79.js";import"./asyncComputed.492220e2.js";import"./index.a7e05125.js";import"./Avatar.c72f4a46.js";import"./index.31f5d814.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="eeb9b01a-f55c-42b7-8e7c-1de61005ec08",e._sentryDebugIdIdentifier="sentry-dbid-eeb9b01a-f55c-42b7-8e7c-1de61005ec08")}catch{}})();const I=p({props:{loading:{type:Boolean,default:!0},color:{type:String,default:"#ea576a"},size:{type:String,default:"10px"},radius:{type:String,default:"100%"}},setup(e){const o=m({spinnerStyle:{width:e.size,height:e.size,borderRadius:e.radius,backgroundColor:e.color}});return{...b(o)}}});const D={class:"v-spinner"};function P(e,o,r,c,d,l){return v((_(),h("div",D,[s("div",{class:"v-beat v-beat-odd",style:a(e.spinnerStyle)},null,4),s("div",{class:"v-beat v-beat-even",style:a(e.spinnerStyle)},null,4),s("div",{class:"v-beat v-beat-odd",style:a(e.spinnerStyle)},null,4)],512)),[[g,e.loading]])}const K=u(I,[["render",P],["__scopeId","data-v-06538001"]]),R={class:"content"},j=p({__name:"ProjectLogin",setup(e){const o=w(),r=S(),c=x();function d(){const t=new URL(location.href);t.searchParams.delete("api-key"),r.replace(t.pathname+t.search)}function l(){const t=o.query["api-key"];if(typeof t=="string")return t}return k(async()=>{const t=l();if(!t){r.push({name:"error"});return}await c.createLogin(t).then(d),r.push({name:"workspace"})}),(t,z)=>(_(),L(y,null,{navbar:n(()=>[i($(B),{style:{padding:"5px 25px",border:"1px solid #f0f0f0"}},{title:n(()=>[i(f)]),_:1})]),content:n(()=>[s("div",R,[i(K)])]),_:1}))}});const Z=u(j,[["__scopeId","data-v-944edebb"]]);export{Z as default};
//# sourceMappingURL=ProjectLogin.6a45ee9e.js.map
