import{_ as n,C as p}from"./View.vue_vue_type_script_setup_true_lang.72d99a58.js";import{d as i,ed as s,c as a,u as m,o as c}from"./vue-router.c5124aea.js";import"./gateway.f0a8a4c2.js";import"./popupNotifcation.13f7057e.js";import"./fetch.06388243.js";import"./record.3c40de6b.js";import"./SaveButton.489ca336.js";import"./UnsavedChangesHandler.64f4045a.js";import"./ExclamationCircleOutlined.1a9a7b13.js";import"./CrudView.c3cfdbe0.js";import"./router.09f8c7fd.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.ee60e4e5.js";import"./BookOutlined.4a8c6e69.js";import"./url.a882d197.js";import"./PhDotsThreeVertical.vue.db7af6ac.js";import"./Badge.2abe7f2d.js";import"./index.31f5d814.js";import"./asyncComputed.492220e2.js";import"./polling.0af81052.js";import"./PhPencil.vue.2e11b63b.js";import"./index.ccd591d2.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="b603e5ab-4819-4a19-9ca5-43d637c2c48b",o._sentryDebugIdIdentifier="sentry-dbid-b603e5ab-4819-4a19-9ca5-43d637c2c48b")}catch{}})();const z=i({__name:"EnvVars",setup(o){const e=s().params.projectId,t=new p(e);return(d,u)=>(c(),a(n,{"env-var-repository":m(t),mode:"console"},null,8,["env-var-repository"]))}});export{z as default};
//# sourceMappingURL=EnvVars.7498558b.js.map
