import{b as l,eh as u,eP as d}from"./vue-router.c5124aea.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="730d18a8-bb86-4218-9f19-0b2a2405fa66",e._sentryDebugIdIdentifier="sentry-dbid-730d18a8-bb86-4218-9f19-0b2a2405fa66")}catch{}})();function i(e){for(var t=1;t<arguments.length;t++){var n=arguments[t]!=null?Object(arguments[t]):{},r=Object.keys(n);typeof Object.getOwnPropertySymbols=="function"&&(r=r.concat(Object.getOwnPropertySymbols(n).filter(function(a){return Object.getOwnPropertyDescriptor(n,a).enumerable}))),r.forEach(function(a){o(e,a,n[a])})}return e}function o(e,t,n){return t in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}var f=function(t,n){var r=i({},t,n.attrs);return l(u,i({},r,{icon:d}),null)};f.displayName="DeleteOutlined";f.inheritAttrs=!1;const c=f;export{c as D};
//# sourceMappingURL=DeleteOutlined.b28c52e2.js.map
