import"./vue-router.c5124aea.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[n]="d1ea888b-e347-4085-aaf3-5e5b16aa5b13",e._sentryDebugIdIdentifier="sentry-dbid-d1ea888b-e347-4085-aaf3-5e5b16aa5b13")}catch{}})();const d=e=>{let n=e.columns.join(",")+`
`;e.rows.forEach(o=>{n+=o.join(","),n+=`
`});const a=document.createElement("a");a.href="data:text/csv;charset=utf-8,"+encodeURIComponent(n),a.target="_blank",a.download=`${e.fileName}.csv`,a.click()};export{d};
//# sourceMappingURL=utils.4e8fd924.js.map
