import{S as s,dA as c,dB as i}from"./vue-router.c5124aea.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},d=new Error().stack;d&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[d]="69e820d3-5c27-4846-8d17-19ed4a860abf",e._sentryDebugIdIdentifier="sentry-dbid-69e820d3-5c27-4846-8d17-19ed4a860abf")}catch{}})();const{DatePicker:n,WeekPicker:t,MonthPicker:r,YearPicker:f,TimePicker:m,QuarterPicker:a,RangePicker:o}=c(i),y=s(n,{WeekPicker:t,MonthPicker:r,YearPicker:f,RangePicker:o,TimePicker:m,QuarterPicker:a,install:e=>(e.component(n.name,n),e.component(o.name,o),e.component(r.name,r),e.component(t.name,t),e.component(a.name,a),e)});export{y as D,r as M,a as Q,o as R,t as W};
//# sourceMappingURL=dayjs.7eb6b577.js.map
