import"./App.vue_vue_type_style_index_0_lang.aeb1ab50.js";import{_ as m}from"./App.vue_vue_type_style_index_0_lang.aeb1ab50.js";import"./workspaceStore.9d8638ec.js";import"./vue-router.c5124aea.js";import"./url.a882d197.js";import"./colorHelpers.89979f79.js";import"./PlayerConfigProvider.2d895a99.js";import"./index.155c96bd.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="0e2c0528-f470-4947-9c1b-920a8cd87b6f",e._sentryDebugIdIdentifier="sentry-dbid-0e2c0528-f470-4947-9c1b-920a8cd87b6f")}catch{}})();export{m as default};
//# sourceMappingURL=App.bdcc9388.js.map
