import{k as i,T as n,m as r,P as o,C as p,M as d,s as c,n as s,p as f,q as m,t as u,v as g}from"./vue-router.c5124aea.js";import{s as y,c as l,a}from"./workspaceStore.9d8638ec.js";import{_ as w}from"./App.vue_vue_type_style_index_0_lang.aeb1ab50.js";import"./url.a882d197.js";import"./colorHelpers.89979f79.js";import"./PlayerConfigProvider.2d895a99.js";import"./index.155c96bd.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="68f18e71-e695-4306-a2f0-303ce46faa2a",t._sentryDebugIdIdentifier="sentry-dbid-68f18e71-e695-4306-a2f0-303ce46faa2a")}catch{}})();class _{static init(){setInterval(()=>fetch("/_version"),20*1e3)}}(async()=>{await y();const t=l(),e=i({render:()=>f(w)});n.init(),r(e,a),_.init(),e.use(a),e.use(t),e.use(o),e.mount("#app"),e.component("VSelect",p),e.component("Markdown",d),e.component("Message",c),s(e,m),s(e,u),s(e,g)})();
//# sourceMappingURL=player.d4905f92.js.map
