import{b as r,u as n}from"./workspaceStore.9d8638ec.js";import{W as c}from"./PlayerConfigProvider.2d895a99.js";import{d as i,g as d,r as u,u as o,c as f,w as p,R as l,o as _,b as m}from"./vue-router.c5124aea.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[a]="98a52306-26a2-43b0-916d-5497f5b76113",t._sentryDebugIdIdentifier="sentry-dbid-98a52306-26a2-43b0-916d-5497f5b76113")}catch{}})();const h=i({__name:"App",setup(t){const a=r(),e=n();return e.actions.fetch(),d(()=>a.user,e.actions.fetch),(w,y)=>{const s=u("RouterView");return o(e).state.workspace?(_(),f(c,{key:0,"main-color":o(e).state.workspace.mainColor,background:o(e).state.workspace.theme,"font-family":o(e).state.workspace.fontFamily,locale:o(e).state.workspace.language},{default:p(()=>[m(s,{style:{height:"100vh",width:"100%"}})]),_:1},8,["main-color","background","font-family","locale"])):l("",!0)}}});export{h as _};
//# sourceMappingURL=App.vue_vue_type_style_index_0_lang.aeb1ab50.js.map
