import{$ as n,o,X as d,Z as s,a,R as r}from"./vue-router.c5124aea.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="b506d2d3-b26d-4bc6-bc6f-9ef9d73466ff",e._sentryDebugIdIdentifier="sentry-dbid-b506d2d3-b26d-4bc6-bc6f-9ef9d73466ff")}catch{}})();const f={},c={class:"base-layout"},i={class:"base-middle"},u={key:0,class:"base-footer"};function _(e,t){return o(),d("div",c,[s(e.$slots,"sidebar",{},void 0,!0),a("section",i,[s(e.$slots,"navbar",{},void 0,!0),s(e.$slots,"content",{},void 0,!0),e.$slots.footer?(o(),d("section",u,[s(e.$slots,"footer",{},void 0,!0)])):r("",!0)])])}const y=n(f,[["render",_],["__scopeId","data-v-9ad5be20"]]);export{y as B};
//# sourceMappingURL=BaseLayout.fbdcf663.js.map
