import{a as g}from"./asyncComputed.492220e2.js";import{d as y,ed as _,W as b,u as e,c as w,X as x,b as a,w as o,o as l,d9 as C,aF as p,dd as h,bP as I,a as k,ec as v}from"./vue-router.c5124aea.js";import"./gateway.f0a8a4c2.js";import{O as B}from"./organization.41019896.js";import"./tables.e3d4a0cb.js";import{C as c}from"./router.09f8c7fd.js";import{L as D}from"./LoadingContainer.2d21a590.js";import{A as N}from"./index.6763cab6.js";import{C as z}from"./Card.44cc8533.js";import"./popupNotifcation.13f7057e.js";import"./record.3c40de6b.js";import"./string.243c4431.js";import"./TabPane.d034fd1b.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[n]="f3ca6b26-7d7d-44d7-94ad-1123bb748a3b",t._sentryDebugIdIdentifier="sentry-dbid-f3ca6b26-7d7d-44d7-94ad-1123bb748a3b")}catch{}})();const M={key:1},A={style:{display:"flex","justify-content":"flex-start","font-size":"24px"}},H=y({__name:"Billing",setup(t){const s=_().params.organizationId,{loading:u,result:f}=g(()=>B.get(s));b(()=>{location.search.includes("upgrade")&&c.showNewMessage("I want to upgrade my plan")});const m=()=>c.showNewMessage("I want to upgrade my plan");return(V,j)=>e(u)?(l(),w(D,{key:0})):(l(),x("div",M,[a(e(h),{justify:"space-between",align:"center"},{default:o(()=>[a(e(C),{level:3},{default:o(()=>[p("Current plan")]),_:1})]),_:1}),a(e(N),{style:{"margin-top":"0"}}),a(e(z),{style:{width:"300px"},title:"Plan"},{extra:o(()=>[a(e(I),{onClick:m},{default:o(()=>[p("Upgrade")]),_:1})]),default:o(()=>{var r,i,d;return[k("div",A,v((d=(i=(r=e(f))==null?void 0:r.billingMetadata)==null?void 0:i.plan)!=null?d:"No active plan"),1)]}),_:1})]))}});export{H as default};
//# sourceMappingURL=Billing.2a06ebf5.js.map
