import{P as k}from"./api.c9850817.js";import{b as _}from"./workspaceStore.9d8638ec.js";import{d as w,L as g,N as d,e as v,X as h,b as r,w as T,u as e,c as p,R as m,o as s,$ as K}from"./vue-router.c5124aea.js";import{K as R,_ as I,W as P,P as S,b as V}from"./WorkflowView.2beb9071.js";import{A as l,T as x}from"./TabPane.d034fd1b.js";import"./Card.44cc8533.js";import"./fetch.06388243.js";import"./metadata.3563316e.js";import"./PhBug.vue.aa92508e.js";import"./PhCheckCircle.vue.7bd19eba.js";import"./PhKanban.vue.f0c956cb.js";import"./PhWebhooksLogo.vue.6c16e7ea.js";import"./url.a882d197.js";import"./colorHelpers.89979f79.js";import"./polling.0af81052.js";import"./asyncComputed.492220e2.js";import"./PhQuestion.vue.b96fa7b2.js";import"./ant-design.8d54eea4.js";import"./index.31f5d814.js";import"./index.ab21d327.js";import"./index.ef3569d7.js";import"./CollapsePanel.056a32ae.js";import"./index.6763cab6.js";import"./index.2d35ff65.js";import"./Badge.2abe7f2d.js";import"./PhArrowCounterClockwise.vue.e4dedd55.js";import"./Workflow.37a53477.js";import"./validations.d974ced3.js";import"./string.243c4431.js";import"./uuid.e585e323.js";import"./index.155c96bd.js";import"./workspaces.7fd2e728.js";import"./record.3c40de6b.js";import"./index.1c47d0a7.js";import"./PhArrowDown.vue.8f545c64.js";import"./LoadingOutlined.e0624b0a.js";import"./DeleteOutlined.b28c52e2.js";import"./PhDownloadSimple.vue.cf64ee19.js";import"./utils.4e8fd924.js";import"./LoadingContainer.2d21a590.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},n=new Error().stack;n&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[n]="078081f1-c86e-45a2-86d3-8e83b6c88ac6",t._sentryDebugIdIdentifier="sentry-dbid-078081f1-c86e-45a2-86d3-8e83b6c88ac6")}catch{}})();const W={class:"threads-view"},A=w({__name:"Threads",setup(t){const a=_().authHeaders,b=new k(a),i=new S(a),u=new V(a),y=new g(d.array(d.string()),"kanban-selected-stages"),o=v("kanban");return(B,c)=>(s(),h("div",W,[r(e(x),{activeKey:o.value,"onUpdate:activeKey":c[0]||(c[0]=f=>o.value=f)},{default:T(()=>[r(e(l),{key:"kanban",tab:"Kanban View"}),r(e(l),{key:"table",tab:"Table View"}),r(e(l),{key:"workflow",tab:"Workflow View"})]),_:1},8,["activeKey"]),o.value==="kanban"?(s(),p(R,{key:0,"kanban-repository":e(i),"kanban-stages-storage":e(y),"stage-run-repository":e(u)},null,8,["kanban-repository","kanban-stages-storage","stage-run-repository"])):m("",!0),o.value==="table"?(s(),p(I,{key:1,"kanban-repository":e(i)},null,8,["kanban-repository"])):m("",!0),o.value==="workflow"?(s(),p(P,{key:2,"kanban-repository":e(i),"workflow-api":e(b)},null,8,["kanban-repository","workflow-api"])):m("",!0)]))}});const ge=K(A,[["__scopeId","data-v-d2894db4"]]);export{ge as default};
//# sourceMappingURL=Threads.b5ef8b1c.js.map
