import{P as m}from"./PlayerNavbar.54c18dbd.js";import{u as f,i as g}from"./workspaceStore.9d8638ec.js";import{d as h,eq as y,ed as c,e as v,f as k,r as w,X as b,u as n,c as L,R as I,a as N,b as C,o as i,$ as R}from"./vue-router.c5124aea.js";import"./metadata.3563316e.js";import"./PhBug.vue.aa92508e.js";import"./PhCheckCircle.vue.7bd19eba.js";import"./PhKanban.vue.f0c956cb.js";import"./PhWebhooksLogo.vue.6c16e7ea.js";import"./LoadingOutlined.e0624b0a.js";import"./PhSignOut.vue.c062efb6.js";import"./index.a7e05125.js";import"./Avatar.c72f4a46.js";import"./url.a882d197.js";import"./colorHelpers.89979f79.js";(function(){try{var t=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(t._sentryDebugIds=t._sentryDebugIds||{},t._sentryDebugIds[e]="044c6146-c461-4c37-9030-82a970f450c2",t._sentryDebugIdIdentifier="sentry-dbid-044c6146-c461-4c37-9030-82a970f450c2")}catch{}})();const V={class:"main-container"},x={class:"content"},B=h({__name:"Main",setup(t){const e=y(),o=f(),u=c().path,a=v(null),p=async({path:r,id:s})=>{a.value=s,await e.push({path:`/${r}`}),a.value=null},d=()=>{e.push({name:"playerLogin"})},l=k(()=>!!c().meta.hideLogin);return g(()=>e.push({name:"playerLogin"})),(r,s)=>{const _=w("RouterView");return i(),b("div",V,[n(o).state.workspace?(i(),L(m,{key:0,"current-path":n(u),"hide-login":l.value,"runner-data":n(o).state.workspace,loading:a.value,onNavigate:p,onLoginClick:d},null,8,["current-path","hide-login","runner-data","loading"])):I("",!0),N("section",x,[C(_)])])}}});const H=R(B,[["__scopeId","data-v-f6aef10c"]]);export{H as default};
//# sourceMappingURL=Main.0e0af444.js.map
