import"./vue-router.c5124aea.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},d=new Error().stack;d&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[d]="95b6db21-1e2a-43bb-afc9-bff77fd93471",e._sentryDebugIdIdentifier="sentry-dbid-95b6db21-1e2a-43bb-afc9-bff77fd93471")}catch{}})();const t=(...e)=>window.fetch(...e);export{t as l};
//# sourceMappingURL=fetch.06388243.js.map
