import{_}from"./Login.vue_vue_type_script_setup_true_lang.c70390da.js";import{b as m,u as l}from"./workspaceStore.9d8638ec.js";import{d as f,eq as b,ed as y,X as g,b as w,u as d,o as k,$ as h}from"./vue-router.c5124aea.js";import"./Logo.b4a8ebe2.js";import"./CircularLoading.ce09a3f2.js";import"./index.ccd591d2.js";import"./url.a882d197.js";import"./colorHelpers.89979f79.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="30831530-d8a4-425a-a61a-1be9e397ca99",e._sentryDebugIdIdentifier="sentry-dbid-30831530-d8a4-425a-a61a-1be9e397ca99")}catch{}})();const v={class:"runner"},I=f({__name:"Login",setup(e){const o=b(),r=y(),i=m(),s=l(),p=async()=>{await i.signUp();const{redirect:t,...a}=r.query;if(t){await o.push({path:t,query:a,params:r.params});return}o.push({name:"playerHome",query:a})};return(t,a)=>{var n,c,u;return k(),g("div",v,[w(_,{"logo-url":(c=(n=d(s).state.workspace)==null?void 0:n.logoUrl)!=null?c:void 0,"brand-name":(u=d(s).state.workspace)==null?void 0:u.brandName,onDone:p},null,8,["logo-url","brand-name"])])}}});const N=h(I,[["__scopeId","data-v-907be835"]]);export{N as default};
//# sourceMappingURL=Login.5da79f68.js.map
