import{d as n,X as s,a as d,Z as a,ea as r,o as l,$ as _}from"./vue-router.c5124aea.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="92b98883-d69a-4801-bb6d-b62e39e06b18",e._sentryDebugIdIdentifier="sentry-dbid-92b98883-d69a-4801-bb6d-b62e39e06b18")}catch{}})();const u={class:"content-layout"},c=n({__name:"ContentLayout",props:{fullWidth:{type:Boolean}},setup(e){return(t,o)=>(l(),s("div",u,[d("div",{class:r(["centered-layout",{"full-width":t.fullWidth}])},[a(t.$slots,"default",{},void 0,!0)],2)]))}});const f=_(c,[["__scopeId","data-v-6397d501"]]);export{f as C};
//# sourceMappingURL=ContentLayout.9b24f578.js.map
