import{d as i,c as p,w as n,o as m,b as s,u as t}from"./vue-router.c5124aea.js";import"./editor.3f12aea3.js";import{W as a}from"./workspaces.7fd2e728.js";import{C as d}from"./ContentLayout.9b24f578.js";import{_ as f,E as c}from"./View.vue_vue_type_script_setup_true_lang.72d99a58.js";import"./workspaceStore.9d8638ec.js";import"./url.a882d197.js";import"./colorHelpers.89979f79.js";import"./asyncComputed.492220e2.js";import"./record.3c40de6b.js";import"./gateway.f0a8a4c2.js";import"./popupNotifcation.13f7057e.js";import"./fetch.06388243.js";import"./SaveButton.489ca336.js";import"./UnsavedChangesHandler.64f4045a.js";import"./ExclamationCircleOutlined.1a9a7b13.js";import"./CrudView.c3cfdbe0.js";import"./router.09f8c7fd.js";import"./DocsButton.vue_vue_type_script_setup_true_lang.ee60e4e5.js";import"./BookOutlined.4a8c6e69.js";import"./PhDotsThreeVertical.vue.db7af6ac.js";import"./Badge.2abe7f2d.js";import"./index.31f5d814.js";import"./polling.0af81052.js";import"./PhPencil.vue.2e11b63b.js";import"./index.ccd591d2.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="d4741892-9604-4dd3-81b9-a81811c41f50",o._sentryDebugIdIdentifier="sentry-dbid-d4741892-9604-4dd3-81b9-a81811c41f50")}catch{}})();const F=i({__name:"EnvVarsEditor",setup(o){const r=new c;return(e,u)=>(m(),p(d,null,{default:n(()=>[s(f,{"env-var-repository":t(r),mode:"editor","file-opener":t(a)},null,8,["env-var-repository","file-opener"])]),_:1}))}});export{F as default};
//# sourceMappingURL=EnvVarsEditor.1a5f447b.js.map
